# Django
from django.template import Context, Template
from django.test import TestCase

# AA Templates: Terra Nanotech
from tnnt_templates import __version__


class TestTnntTemplateVariables(TestCase):
    """
    Test TN-NT Template tags
    """

    def test_startswith(self):
        """
        Test startswith
        :return:
        :rtype:
        """

        context = Context(
            {"content": "Lorem ipsum dolor sit amet, consectetur adipiscing elit."}
        )
        template_to_render = Template(
            "{% load tnnt_template_tags %}"
            '{% if content|startswith:"Lorem" %}{{ content }}{% endif %}'
        )

        rendered_template = template_to_render.render(context)

        self.assertInHTML(
            "Lorem ipsum dolor sit amet, consectetur adipiscing elit.",
            rendered_template,
        )

    def test_tnnt_static(self):
        """
        Test tnnt_static
        :return:
        :rtype:
        """

        context = Context({"version": __version__})
        template_to_render = Template(
            "{% load tnnt_template_tags %}"
            "{% tnnt_static 'tnnt_templates/css/fonts.min.css' %}"
        )

        rendered_template = template_to_render.render(context)

        self.assertInHTML(
            f'/static/tnnt_templates/css/fonts.min.css?v={context["version"]}',
            rendered_template,
        )



"""
Template filter for Terra Nanotech templates
"""

# Django
from django.apps import apps
from django.template.defaulttags import register
from django.templatetags.static import static

# AA Templates: Terra Nanotech
from tnnt_templates import __version__


@register.filter
def startswith(value, arg):
    """
    Usage, {% if value|starts_with:"arg" %}
    """

    return value.startswith(arg)


@register.simple_tag
def tnnt_static(path: str) -> str:
    """
    Versioned static URL
    :param path:
    :type path:
    :return:
    :rtype:
    """

    static_url = static(path)
    versioned_url = static_url + "?v=" + __version__

    return versioned_url


@register.simple_tag
def is_app_installed(app_name):
    """
    Check if a Django app is installed

    Usage:
    ```django
    {% load my_filters %}

    {% is_app_installed "myapp" as is_myapp_installed %}
    {% if is_myapp_installed %}
        ...
    {% endif %}
    ```
    :param app_name:
    :return:
    """

    return apps.is_installed(app_name)
